/**
 * Namespace Api
 *
 * All backend api type
 */
declare namespace Api {
  /**
   * namespace Monitor
   *
   * backend api module: "monitor"
   */
  namespace Monitor {
    /** oper log */
    type OperLog = Common.CommonRecord<{
      /** 日志主键 */
      operId: CommonType.IdType;
      /** 租户编号 */
      tenantId: CommonType.IdType;
      /** 系统模块 */
      title: string;
      /** 操作类型 */
      businessType: number;
      /** 方法名称 */
      method: string;
      /** 请求方式 */
      requestMethod: string;
      /** 操作类别 */
      operatorType: number;
      /** 操作人员 */
      operName: string;
      /** 部门名称 */
      deptName: string;
      /** 请求URL */
      operUrl: string;
      /** 操作IP */
      operIp: string;
      /** 操作地点 */
      operLocation: string;
      /** 请求参数 */
      operParam: string;
      /** 返回参数 */
      jsonResult: string;
      /** 操作状态 */
      status: number;
      /** 错误消息 */
      errorMsg: string;
      /** 操作时间 */
      operTime: string;
      /** 消耗时间 */
      costTime: number;
    }>;

    /** oper log search params */
    type OperLogSearchParams = CommonType.RecordNullable<
      Pick<Api.Monitor.OperLog, 'title' | 'businessType' | 'operName' | 'operIp' | 'status' | 'operTime'> &
        Api.Common.CommonSearchParams
    >;

    /** oper log list */
    type OperLogList = Api.Common.PaginatingQueryRecord<OperLog>;

    /** login infor */
    type LoginInfor = Common.CommonRecord<{
      /** 访问ID */
      infoId: CommonType.IdType;
      /** 租户编号 */
      tenantId: CommonType.IdType;
      /** 用户账号 */
      userName: string;
      /** 客户端 */
      clientKey: string;
      /** 设备类型 */
      deviceType: string;
      /** 登录IP地址 */
      ipaddr: string;
      /** 登录地点 */
      loginLocation: string;
      /** 浏览器类型 */
      browser: string;
      /** 操作系统 */
      os: string;
      /** 登录状态（0成功 1失败） */
      status: string;
      /** 提示消息 */
      msg: string;
      /** 访问时间 */
      loginTime: string;
    }>;

    /** login infor search params */
    type LoginInforSearchParams = CommonType.RecordNullable<
      Pick<Api.Monitor.LoginInfor, 'userName' | 'ipaddr' | 'status'> & Api.Common.CommonSearchParams
    >;

    /** login infor list */
    type LoginInforList = Api.Common.PaginatingQueryRecord<LoginInfor>;
  }
}
